==> haskell-texmath-0.9.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: texmath
version: 0.9.4
id: texmath-0.9.4-CnDyr8uDosMGWSO47WHkmU
key: texmath-0.9.4-CnDyr8uDosMGWSO47WHkmU
license: GPL
maintainer: jgm@berkeley.edu
stability: Experimental
homepage: http://github.com/jgm/texmath
synopsis: Conversion between formats used to represent mathematics.
description:
    The texmath library provides functions to read and
    write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).
    Support is also included for converting math formats
    to Gnu eqn and to pandoc'\''s native format (allowing
    conversion, via pandoc, to a variety of different
    markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX
    macros.  (See <http://johnmacfarlane.net/texmath here>
    for a live demo of bidirectional conversion between LaTeX
    and MathML.)
    .
    The package also includes several utility modules which
    may be useful for anyone looking to manipulate either
    TeX math or MathML.  For example, a copy of the MathML
    operator dictionary is included.
    .
    Use the @executable@ flag to install a standalone
    executable, @texmath@, that by default reads a LaTeX
    formula from @stdin@ and writes MathML to @stdout@.
    With flags all the functionality exposed by
    '\''Text.TeXMath'\'' can be accessed through this executable.
    (Use the @--help@ flag for a description of all
    functionality)
    .
    The @texmath@ executable can also be used as a CGI
    script, when renamed as @texmath-cgi@.
    It will expect query parameters for @from@, @to@,
    @input@, and optionally @inline@, and return a JSON
    object with either @error@ and a message or
    @success@ and the converted result.
category: Text
author: John MacFarlane, Matthew Pickering
exposed: True
exposed-modules:
    Text.TeXMath Text.TeXMath.Types Text.TeXMath.Readers.TeX
    Text.TeXMath.Readers.TeX.Macros Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.MMLDict
    Text.TeXMath.Readers.MathML.EntityMap Text.TeXMath.Readers.OMML
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
    Text.TeXMath.Writers.Eqn Text.TeXMath.Unicode.ToUnicode
    Text.TeXMath.Unicode.ToTeX Text.TeXMath.Unicode.ToASCII
    Text.TeXMath.Unicode.Fonts
hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                Text.TeXMath.TeX Paths_texmath
abi: 6944f4457169b13d02d496d0ffe33c91
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/texmath-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/texmath-0.9.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/texmath-0.9.4
hs-libraries: HStexmath-0.9.4-CnDyr8uDosMGWSO47WHkmU
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-types-1.17.0.5-11Nd20rWWmXXKwn0ardsS
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY syb-0.6-C65vWCsht6A8uLstpQIXyj
    xml-1.3.14-rYbwgRBahsKh5Xn1LyTeP
haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html: /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-texmath-0.9.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: texmath
version: 0.9.4
id: texmath-0.9.4-EIBL9FVXBtOC2JXhJU18R9
key: texmath-0.9.4-EIBL9FVXBtOC2JXhJU18R9
license: GPL
maintainer: jgm@berkeley.edu
stability: Experimental
homepage: http://github.com/jgm/texmath
synopsis: Conversion between formats used to represent mathematics.
description:
    The texmath library provides functions to read and
    write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).
    Support is also included for converting math formats
    to Gnu eqn and to pandoc'\''s native format (allowing
    conversion, via pandoc, to a variety of different
    markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX
    macros.  (See <http://johnmacfarlane.net/texmath here>
    for a live demo of bidirectional conversion between LaTeX
    and MathML.)
    .
    The package also includes several utility modules which
    may be useful for anyone looking to manipulate either
    TeX math or MathML.  For example, a copy of the MathML
    operator dictionary is included.
    .
    Use the @executable@ flag to install a standalone
    executable, @texmath@, that by default reads a LaTeX
    formula from @stdin@ and writes MathML to @stdout@.
    With flags all the functionality exposed by
    '\''Text.TeXMath'\'' can be accessed through this executable.
    (Use the @--help@ flag for a description of all
    functionality)
    .
    The @texmath@ executable can also be used as a CGI
    script, when renamed as @texmath-cgi@.
    It will expect query parameters for @from@, @to@,
    @input@, and optionally @inline@, and return a JSON
    object with either @error@ and a message or
    @success@ and the converted result.
category: Text
author: John MacFarlane, Matthew Pickering
exposed: True
exposed-modules:
    Text.TeXMath Text.TeXMath.Types Text.TeXMath.Readers.TeX
    Text.TeXMath.Readers.TeX.Macros Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.MMLDict
    Text.TeXMath.Readers.MathML.EntityMap Text.TeXMath.Readers.OMML
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
    Text.TeXMath.Writers.Eqn Text.TeXMath.Unicode.ToUnicode
    Text.TeXMath.Unicode.ToTeX Text.TeXMath.Unicode.ToASCII
    Text.TeXMath.Unicode.Fonts
hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                Text.TeXMath.TeX Paths_texmath
abi: 0233ce3477171837f615cec1ee5537e5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/texmath-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/texmath-0.9.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/texmath-0.9.4
hs-libraries: HStexmath-0.9.4-EIBL9FVXBtOC2JXhJU18R9
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-types-1.17.0.5-8dxYXX3Q5qWEyBUUdZ0nWu
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr syb-0.6-C65vWCsht6A8uLstpQIXyj
    xml-1.3.14-9IpHbL0QRqR5eAZpdkwTMQ
haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html: /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
